==> monodevelop-2.4.tar.bz2: monodevelop-2.4/src/core/Mono.Texteditor/Mono.TextEditor.Highlighting/Chunk.cs <==
// Chunk.cs
//
// Author:
//   Mike Krüger <mkrueger@novell.com>
//
// Copyright (c) 2007 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
//
//

using System;
using Mono.TextEditor.Highlighting;

namespace Mono.TextEditor
{
	public class Chunk : Segment
	{
		public virtual ChunkStyle GetChunkStyle (Style style)
		{
			if (style == null)
				return null;
			return style.GetChunkStyle (Style);
		}

		public Chunk Next {
			get;
			set;
		}
		
		public string Style {
			get;
			set;
		}
		
		public Chunk ()
		{
			Next = null;
		}
		
		public Chunk (int offset, int length, string styleName) : base (offset, length)
		{
			this.Style = styleName;
		}

		
		public virtual string GetText (Document doc)
		{
			return doc.GetTextAt (this);
		}
		public virtual char GetCharAt (Document doc, int offset)
		{
			return doc.GetCharAt (offset);
		}
	}
}

==> monodevelop-2.8.8.4.tar.bz2: monodevelop-2.8.8.4/src/core/Mono.Texteditor/Mono.TextEditor.Highlighting/Chunk.cs <==
// Chunk.cs
//
// Author:
//   Mike Krüger <mkrueger@novell.com>
//
// Copyright (c) 2007 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
//
//

using System;
using Mono.TextEditor.Highlighting;

namespace Mono.TextEditor
{
	public class Chunk : Segment
	{
		public virtual ChunkStyle GetChunkStyle (ColorSheme style)
		{
			if (style == null)
				return null;
			return style.GetChunkStyle (Style);
		}

		public Chunk Next {
			get;
			set;
		}

		public string Style {
			get;
			set;
		}

		CloneableStack<Span> spanStack;
		static CloneableStack<Span> emptySpan = new CloneableStack<Span> ();
		public CloneableStack<Span> SpanStack {
			get { return spanStack ?? emptySpan; }
			set { spanStack = value; }
		}

		public Chunk ()
		{
			Next = null;
		}
		
		public Chunk (int offset, int length, string styleName) : base (offset, length)
		{
			this.Style = styleName;
		}

		
		public virtual string GetText (Document doc)
		{
			return doc.GetTextAt (this);
		}
		public virtual char GetCharAt (Document doc, int offset)
		{
			return doc.GetCharAt (offset);
		}
	}
}
